"""
wrap telegram bot
need put .env file in the same folder and set TEL_TOKEN CHAT_ID
"""
from .send_photo import send_photo
from .send_message import send_message

__version__ = "0.1.0"
__author__ = 'Big Zhu'
